==> jc-1.4.0.tar.gz: javax/swing/UnsupportedLookAndFeelException.h <==
// public class javax.swing.UnsupportedLookAndFeelException

// class file dependencies
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable
// @dep_class b7693b3f16c46d09 javax_swing_UnsupportedLookAndFeelException

// header file dependencies
// @dep_header java_lang_Exception

#include "java/lang/Exception.h"

#ifndef _JC_javax_swing_UnsupportedLookAndFeelException_H_
#define _JC_javax_swing_UnsupportedLookAndFeelException_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_javax_swing_UnsupportedLookAndFeelException$sub_refs	_jc_javax_swing_UnsupportedLookAndFeelException$sub_refs;
typedef struct _jc_javax_swing_UnsupportedLookAndFeelException$sub_nonrefs	_jc_javax_swing_UnsupportedLookAndFeelException$sub_nonrefs;
typedef struct _jc_javax_swing_UnsupportedLookAndFeelException$refs	_jc_javax_swing_UnsupportedLookAndFeelException$refs;
typedef struct _jc_javax_swing_UnsupportedLookAndFeelException$nonrefs	_jc_javax_swing_UnsupportedLookAndFeelException$nonrefs;
typedef struct _jc_javax_swing_UnsupportedLookAndFeelException$object	_jc_javax_swing_UnsupportedLookAndFeelException$object;

typedef const struct _jc_javax_swing_UnsupportedLookAndFeelException$vmethods	_jc_javax_swing_UnsupportedLookAndFeelException$vmethods;
typedef const struct _jc_javax_swing_UnsupportedLookAndFeelException$vtable	_jc_javax_swing_UnsupportedLookAndFeelException$vtable;
typedef const struct _jc_javax_swing_UnsupportedLookAndFeelException$vtype	_jc_javax_swing_UnsupportedLookAndFeelException$vtype;

// Constructors
extern void _jc_javax_swing_UnsupportedLookAndFeelException$method$_init$c31b894660454d13(_jc_env *, struct _jc_javax_swing_UnsupportedLookAndFeelException$object *, struct _jc_java_lang_String$object *);

// Virtual methods structure
struct _jc_javax_swing_UnsupportedLookAndFeelException$vmethods {
};

// Vtable
struct _jc_javax_swing_UnsupportedLookAndFeelException$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Exception$vmethods	java_lang_Exception;
	_jc_javax_swing_UnsupportedLookAndFeelException$vmethods	javax_swing_UnsupportedLookAndFeelException;
};

// Vtype
struct _jc_javax_swing_UnsupportedLookAndFeelException$vtype {
	_jc_type			type;
	_jc_javax_swing_UnsupportedLookAndFeelException$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_UnsupportedLookAndFeelException$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_swing_UnsupportedLookAndFeelException$refs {
    _jc_javax_swing_UnsupportedLookAndFeelException$sub_refs	javax_swing_UnsupportedLookAndFeelException;
    _jc_java_lang_Exception$sub_refs	java_lang_Exception;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_UnsupportedLookAndFeelException$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_UnsupportedLookAndFeelException$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Exception$sub_nonrefs	java_lang_Exception;
    _jc_javax_swing_UnsupportedLookAndFeelException$sub_nonrefs	javax_swing_UnsupportedLookAndFeelException;
};

// Object instance structure
struct _jc_javax_swing_UnsupportedLookAndFeelException$object {
	_jc_javax_swing_UnsupportedLookAndFeelException$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_UnsupportedLookAndFeelException$vtype	*vtype;
	_jc_javax_swing_UnsupportedLookAndFeelException$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_UnsupportedLookAndFeelException$vtype _jc_javax_swing_UnsupportedLookAndFeelException$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_UnsupportedLookAndFeelException, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_UnsupportedLookAndFeelException$class_object;

#endif	/* _JC_javax_swing_UnsupportedLookAndFeelException_H_ */

==> jc-1.4.6.tar.gz: javax/swing/UnsupportedLookAndFeelException.h <==
// public class javax.swing.UnsupportedLookAndFeelException

// class file dependencies
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable
// @dep_class b7693b3f16c46d09 javax_swing_UnsupportedLookAndFeelException

// header file dependencies
// @dep_header java_lang_Exception

#include "java/lang/Exception.h"

#ifndef _JC_javax_swing_UnsupportedLookAndFeelException_H_
#define _JC_javax_swing_UnsupportedLookAndFeelException_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_javax_swing_UnsupportedLookAndFeelException$sub_refs	_jc_javax_swing_UnsupportedLookAndFeelException$sub_refs;
typedef struct _jc_javax_swing_UnsupportedLookAndFeelException$sub_nonrefs	_jc_javax_swing_UnsupportedLookAndFeelException$sub_nonrefs;
typedef struct _jc_javax_swing_UnsupportedLookAndFeelException$refs	_jc_javax_swing_UnsupportedLookAndFeelException$refs;
typedef struct _jc_javax_swing_UnsupportedLookAndFeelException$nonrefs	_jc_javax_swing_UnsupportedLookAndFeelException$nonrefs;
typedef struct _jc_javax_swing_UnsupportedLookAndFeelException$object	_jc_javax_swing_UnsupportedLookAndFeelException$object;

typedef const struct _jc_javax_swing_UnsupportedLookAndFeelException$vmethods	_jc_javax_swing_UnsupportedLookAndFeelException$vmethods;
typedef const struct _jc_javax_swing_UnsupportedLookAndFeelException$vtable	_jc_javax_swing_UnsupportedLookAndFeelException$vtable;
typedef const struct _jc_javax_swing_UnsupportedLookAndFeelException$vtype	_jc_javax_swing_UnsupportedLookAndFeelException$vtype;

// Constructors
extern void _jc_javax_swing_UnsupportedLookAndFeelException$method$_init$c31b894660454d13(_jc_env *, struct _jc_javax_swing_UnsupportedLookAndFeelException$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_javax_swing_UnsupportedLookAndFeelException$vmethods {
};

// Vtable
struct _jc_javax_swing_UnsupportedLookAndFeelException$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Exception$vmethods	java_lang_Exception;
	_jc_javax_swing_UnsupportedLookAndFeelException$vmethods	javax_swing_UnsupportedLookAndFeelException;
};

// Vtype
struct _jc_javax_swing_UnsupportedLookAndFeelException$vtype {
	_jc_type			type;
	_jc_javax_swing_UnsupportedLookAndFeelException$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_UnsupportedLookAndFeelException$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_swing_UnsupportedLookAndFeelException$refs {
    _jc_javax_swing_UnsupportedLookAndFeelException$sub_refs	javax_swing_UnsupportedLookAndFeelException;
    _jc_java_lang_Exception$sub_refs	java_lang_Exception;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_UnsupportedLookAndFeelException$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_UnsupportedLookAndFeelException$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Exception$sub_nonrefs	java_lang_Exception;
    _jc_javax_swing_UnsupportedLookAndFeelException$sub_nonrefs	javax_swing_UnsupportedLookAndFeelException;
};

// Object instance structure
struct _jc_javax_swing_UnsupportedLookAndFeelException$object {
	_jc_javax_swing_UnsupportedLookAndFeelException$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_UnsupportedLookAndFeelException$vtype	*vtype;
	_jc_javax_swing_UnsupportedLookAndFeelException$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_UnsupportedLookAndFeelException$vtype _jc_javax_swing_UnsupportedLookAndFeelException$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_UnsupportedLookAndFeelException, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_UnsupportedLookAndFeelException$class_object;

#endif	/* _JC_javax_swing_UnsupportedLookAndFeelException_H_ */
